@@ -96,9 +96,8 @@ void CategoryWidget::setCategories(const QStringList &categoryList)
     mWidgets->mCategories->clear();
     mCategoryList.clear();
 
-    QStringList::ConstIterator it;
     QStringList cats = mCategoryConfig->customCategories();
-    for (it = categoryList.begin(); it != categoryList.end(); ++it) {
+    for (QStringList::ConstIterator it = categoryList.begin(), end = categoryList.end(); it != end; ++it) {
         if (!cats.contains(*it)) {
             cats.append(*it);
         }
@@ -132,7 +131,7 @@ static QStringList getSelectedCategories(AutoCheckTreeWidget *categoriesView)
     while (*it) {
         QStringList path = categoriesView->pathByItem(*it++);
         if (path.count()) {
-            path.replaceInStrings(CategoryConfig::categorySeparator, QStringLiteral("\\") +
+            path.replaceInStrings(CategoryConfig::categorySeparator, QLatin1Char('\\') +
                                   CategoryConfig::categorySeparator);
             categories.append(path.join(CategoryConfig::categorySeparator));
         }
@@ -231,14 +230,11 @@ void CategoryWidget::handleColorChanged(const QColor &newColor)
 }
 
 CategoryDialog::CategoryDialog(CategoryConfig *cc, QWidget *parent)
-    : QDialog(parent), d(0)
+    : QDialog(parent), d(nullptr)
 {
     setWindowTitle(i18n("Select Categories"));
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
-    QDialogButtonBox *buttonBox = 0;
-
-    buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel /*| QDialogButtonBox::Help*/ | QDialogButtonBox::Apply);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel /*| QDialogButtonBox::Help*/ | QDialogButtonBox::Apply, this);
 
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
@@ -284,7 +280,7 @@ void CategoryDialog::slotApply()
         path = mWidgets->listView()->pathByItem(*it++);
         path.replaceInStrings(
             CategoryConfig::categorySeparator,
-            QStringLiteral("\\") + CategoryConfig::categorySeparator);
+            QLatin1Char('\\') + CategoryConfig::categorySeparator);
         l.append(path.join(CategoryConfig::categorySeparator));
     }
     mCategoryConfig->setCustomCategories(l);
