@@ -78,9 +78,8 @@ void CategorySelectWidget::setCategories(const QStringList &categoryList)
     mWidgets->mCategories->clear();
     mCategoryList.clear();
 
-    QStringList::ConstIterator it;
     QStringList cats = mCategoryConfig->customCategories();
-    for (it = categoryList.begin(); it != categoryList.end(); ++it) {
+    for (QStringList::ConstIterator it = categoryList.begin(), end = categoryList.end(); it != end; ++it) {
         if (!cats.contains(*it)) {
             cats.append(*it);
         }
@@ -114,7 +113,7 @@ static QStringList getSelectedCategoriesFromCategoriesView(AutoCheckTreeWidget *
     while (*it) {
         QStringList path = categoriesView->pathByItem(*it++);
         if (path.count()) {
-            path.replaceInStrings(CategoryConfig::categorySeparator, QStringLiteral("\\") +
+            path.replaceInStrings(CategoryConfig::categorySeparator, QLatin1Char('\\') +
                                   CategoryConfig::categorySeparator);
             categories.append(path.join(CategoryConfig::categorySeparator));
         }
@@ -164,13 +163,12 @@ void CategorySelectWidget::setCategoryList(const QStringList &categories)
 }
 
 CategorySelectDialog::CategorySelectDialog(CategoryConfig *cc, QWidget *parent)
-    : QDialog(parent), d(0)
+    : QDialog(parent), d(nullptr)
 {
     setWindowTitle(i18n("Select Categories"));
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
-    QDialogButtonBox *buttonBox = 0;
-    buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel /*| QDialogButtonBox::Help*/ | QDialogButtonBox::Apply);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    QDialogButtonBox *buttonBox = nullptr;
+    buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel /*| QDialogButtonBox::Help*/ | QDialogButtonBox::Apply, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
