@@ -80,7 +80,7 @@ public:
 };
 
 ItemEditorPrivate::ItemEditorPrivate(Akonadi::IncidenceChanger *changer, EditorItemManager *qq)
-    : q_ptr(qq), mItemMonitor(0), mIsCounterProposal(false)
+    : q_ptr(qq), mItemMonitor(nullptr), mIsCounterProposal(false)
     , currentAction(EditorItemManager::None)
 {
     mFetchScope.fetchFullPayload();
